@@ -198,6 +198,8 @@ def init_anat_preproc_wf(
         subject space to T1w
     surfaces
         GIFTI surfaces (gray/white boundary, midthickness, pial, inflated)
+    morphometrics
+        GIFTIs of cortical thickness, curvature, and sulcal depth
 
     See Also
     --------
@@ -545,6 +547,7 @@ the brain-extracted T1w using `fast` [FSL {fsl_ver}, RRID:SCR_002823,
             ('outputnode.t1w2fsnative_xfm', 't1w2fsnative_xfm'),
             ('outputnode.fsnative2t1w_xfm', 'fsnative2t1w_xfm'),
             ('outputnode.surfaces', 'surfaces'),
+            ('outputnode.morphometrics', 'morphometrics'),
             ('outputnode.out_aseg', 't1w_aseg'),
             ('outputnode.out_aparc', 't1w_aparc')]),
         (applyrefined, buffernode, [('out_file', 't1w_brain')]),
@@ -561,6 +564,7 @@ the brain-extracted T1w using `fast` [FSL {fsl_ver}, RRID:SCR_002823,
             ('t1w2fsnative_xfm', 'inputnode.t1w2fsnative_xfm'),
             ('fsnative2t1w_xfm', 'inputnode.fsnative2t1w_xfm'),
             ('surfaces', 'inputnode.surfaces'),
+            ('morphometrics', 'inputnode.morphometrics'),
         ]),
     ])
     # fmt:on
