@@ -262,6 +262,8 @@ def init_anat_derivatives_wf(
         subject space to T1w
     surfaces
         GIFTI surfaces (gray/white boundary, midthickness, pial, inflated)
+    morphometrics
+        GIFTIs of cortical thickness, curvature, and sulcal depth
     t1w_fs_aseg
         FreeSurfer's aseg segmentation, in native T1w space
     t1w_fs_aparc
@@ -287,6 +289,7 @@ def init_anat_derivatives_wf(
                 "t1w2fsnative_xfm",
                 "fsnative2t1w_xfm",
                 "surfaces",
+                "morphometrics",
                 "t1w_fs_aseg",
                 "t1w_fs_aparc",
             ]
@@ -599,6 +602,16 @@ def init_anat_derivatives_wf(
         name="ds_surfs",
         run_without_submitting=True,
     )
+    # Morphometrics
+    name_morphs = pe.MapNode(
+        Path2BIDS(), iterfield="in_file", name="name_morphs", run_without_submitting=True,
+    )
+    ds_morphs = pe.MapNode(
+        DerivativesDataSink(base_directory=output_dir, extension=".shape.gii"),
+        iterfield=["in_file", "hemi", "suffix"],
+        name="ds_morphs",
+        run_without_submitting=True,
+    )
     # Parcellations
     ds_t1w_fsaseg = pe.Node(
         DerivativesDataSink(
@@ -628,6 +641,11 @@ def init_anat_derivatives_wf(
                                ('source_files', 'source_file')]),
         (name_surfs, ds_surfs, [('hemi', 'hemi'),
                                 ('suffix', 'suffix')]),
+        (inputnode, name_morphs, [('morphometrics', 'in_file')]),
+        (inputnode, ds_morphs, [('morphometrics', 'in_file'),
+                                ('source_files', 'source_file')]),
+        (name_morphs, ds_morphs, [('hemi', 'hemi'),
+                                  ('suffix', 'suffix')]),
         (inputnode, ds_t1w_fsaseg, [('t1w_fs_aseg', 'in_file'),
                                     ('source_files', 'source_file')]),
         (inputnode, ds_t1w_fsparc, [('t1w_fs_aparc', 'in_file'),
