@@ -36,7 +36,6 @@ from nipype.interfaces import (
 )
 
 from ..interfaces.freesurfer import ReconAll
-from ..interfaces.surf import NormalizeSurf
 
 from niworkflows.engine.workflows import LiterateWorkflow as Workflow
 from niworkflows.interfaces.freesurfer import (
@@ -159,6 +158,8 @@ def init_surface_recon_wf(*, omp_nthreads, hires, name="surface_recon_wf"):
         FreeSurfer's aseg segmentation, in native T1w space
     out_aparc
         FreeSurfer's aparc+aseg segmentation, in native T1w space
+    morphometrics
+        GIFTIs of cortical thickness, curvature, and sulcal depth
 
     See also
     --------
@@ -203,6 +204,7 @@ gray-matter of Mindboggle [RRID:SCR_002438, @mindboggle].
                 "out_brainmask",
                 "out_aseg",
                 "out_aparc",
+                "morphometrics",
             ]
         ),
         name="outputnode",
@@ -270,8 +272,6 @@ gray-matter of Mindboggle [RRID:SCR_002438, @mindboggle].
         # reoriented image
         (inputnode, fsnative2t1w_xfm, [('t1w', 'target_file')]),
         (autorecon1, fsnative2t1w_xfm, [('T1', 'source_file')]),
-        (fsnative2t1w_xfm, gifti_surface_wf, [
-            ('out_reg_file', 'inputnode.fsnative2t1w_xfm')]),
         (fsnative2t1w_xfm, t1w2fsnative_xfm, [('out_reg_file', 'in_lta')]),
         # Refine ANTs mask, deriving new mask from FS' aseg
         (inputnode, refine, [('corrected_t1', 'in_anat'),
@@ -291,7 +291,8 @@ gray-matter of Mindboggle [RRID:SCR_002438, @mindboggle].
         # Output
         (autorecon_resume_wf, outputnode, [('outputnode.subjects_dir', 'subjects_dir'),
                                            ('outputnode.subject_id', 'subject_id')]),
-        (gifti_surface_wf, outputnode, [('outputnode.surfaces', 'surfaces')]),
+        (gifti_surface_wf, outputnode, [('outputnode.surfaces', 'surfaces'),
+                                        ('outputnode.morphometrics', 'morphometrics')]),
         (t1w2fsnative_xfm, outputnode, [('out_lta', 't1w2fsnative_xfm')]),
         (fsnative2t1w_xfm, outputnode, [('out_reg_file', 'fsnative2t1w_xfm')]),
         (refine, outputnode, [('out_file', 'out_brainmask')]),
@@ -504,15 +505,20 @@ def init_gifti_surface_wf(*, name="gifti_surface_wf"):
     surfaces
         GIFTI surfaces for gray/white matter boundary, pial surface,
         midthickness (or graymid) surface, and inflated surfaces
+    morphometrics
+        GIFTIs of cortical thickness, curvature, and sulcal depth
 
     """
+    from ..interfaces.freesurfer import MRIsConvertData
+    from ..interfaces.surf import NormalizeSurf
+
     workflow = Workflow(name=name)
 
     inputnode = pe.Node(
         niu.IdentityInterface(["subjects_dir", "subject_id", "fsnative2t1w_xfm"]),
         name="inputnode",
     )
-    outputnode = pe.Node(niu.IdentityInterface(["surfaces"]), name="outputnode")
+    outputnode = pe.Node(niu.IdentityInterface(["surfaces", "morphometrics"]), name="outputnode")
 
     get_surfaces = pe.Node(nio.FreeSurferSource(), name="get_surfaces")
 
@@ -532,9 +538,18 @@ def init_gifti_surface_wf(*, name="gifti_surface_wf"):
         run_without_submitting=True,
     )
     fs2gii = pe.MapNode(
-        fs.MRIsConvert(out_datatype="gii", to_scanner=True), iterfield="in_file", name="fs2gii"
+        fs.MRIsConvert(out_datatype="gii", to_scanner=True), iterfield="in_file", name="fs2gii",
     )
     fix_surfs = pe.MapNode(NormalizeSurf(), iterfield="in_file", name="fix_surfs")
+    surfmorph_list = pe.Node(
+        niu.Merge(3, ravel_inputs=True),
+        name="surfmorph_list",
+        run_without_submitting=True,
+    )
+    morphs2gii = pe.MapNode(
+        MRIsConvertData(out_datatype="gii"),
+        iterfield="scalarcurv_file", name="morphs2gii",
+    )
 
     # fmt:off
     workflow.connect([
@@ -555,6 +570,11 @@ def init_gifti_surface_wf(*, name="gifti_surface_wf"):
         (fs2gii, fix_surfs, [('converted', 'in_file')]),
         (inputnode, fix_surfs, [('fsnative2t1w_xfm', 'transform_file')]),
         (fix_surfs, outputnode, [('out_file', 'surfaces')]),
+        (get_surfaces, surfmorph_list, [('thickness', 'in1'),
+                                        ('sulc', 'in2'),
+                                        ('curv', 'in3')]),
+        (surfmorph_list, morphs2gii, [('out', 'scalarcurv_file')]),
+        (morphs2gii, outputnode, [('converted', 'morphometrics')]),
     ])
     # fmt:on
     return workflow
